summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2019-01-10 16:57:30 +0100
committerGitHub <[email protected]>2019-01-10 16:57:30 +0100
commit91ea00747838b38b0db4808ea43124d50d316a1e (patch)
treef1428e583f4ed5ee8c7060c47da55e8ce0194882 /src/raylib.h
parent93471b0a7c75fc675f27fc74dfda281eb8310a7a (diff)
parent56173d7cf457413fd56e26967becc7c5054aa2cf (diff)
downloadraylib-91ea00747838b38b0db4808ea43124d50d316a1e.tar.gz
raylib-91ea00747838b38b0db4808ea43124d50d316a1e.zip
Merge pull request #719 from MarcoLizza/window-visibility
Window visibility
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/raylib.h b/src/raylib.h
index ed863649..b554d10d 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -415,8 +415,9 @@ typedef enum {
FLAG_WINDOW_RESIZABLE = 4, // Set to allow resizable window
FLAG_WINDOW_UNDECORATED = 8, // Set to disable window decoration (frame and buttons)
FLAG_WINDOW_TRANSPARENT = 16, // Set to allow transparent window
- FLAG_MSAA_4X_HINT = 32, // Set to try enabling MSAA 4X
- FLAG_VSYNC_HINT = 64 // Set to try enabling V-Sync on GPU
+ FLAG_WINDOW_HIDDEN = 32, // Set to create the window initially hidden
+ FLAG_MSAA_4X_HINT = 64, // Set to try enabling MSAA 4X
+ FLAG_VSYNC_HINT = 128 // Set to try enabling V-Sync on GPU
} ConfigFlag;
// Trace log type
@@ -844,6 +845,9 @@ RLAPI void SetWindowPosition(int x, int y); // Set window
RLAPI void SetWindowMonitor(int monitor); // Set monitor for the current window (fullscreen mode)
RLAPI void SetWindowMinSize(int width, int height); // Set window minimum dimensions (for FLAG_WINDOW_RESIZABLE)
RLAPI void SetWindowSize(int width, int height); // Set window dimensions
+RLAPI void ShowWindow(); // Show the window
+RLAPI void HideWindow(); // Hide the window
+RLAPI bool IsWindowHidden(); // Check if window is currently hidden
RLAPI int GetScreenWidth(void); // Get current screen width
RLAPI int GetScreenHeight(void); // Get current screen height
RLAPI void *GetWindowHandle(void); // Get native window handle